@@ -1,4 +1,3 @@
-# coding: utf-8
 module Slim
   # Parses Slim code and transforms it to a Temple expression
   # @api private
@@ -19,7 +18,8 @@ module Slim
                    shortcut: {
                      '#' => { attr: 'id' },
                      '.' => { attr: 'class' }
-                   }
+                   },
+                   splat_prefix: '*'
 
     class SyntaxError < StandardError
       attr_reader :error, :file, :line, :lineno, :column
@@ -70,24 +70,28 @@ module Slim
         end
       end
       keys = Regexp.union @attr_shortcut.keys.sort_by {|k| -k.size }
-      @attr_shortcut_re = /\A(#{keys}+)((?:\p{Word}|-)*)/
+      @attr_shortcut_re = /\A(#{keys}+)((?:\p{Word}|-|\/\d+|:(\w|-)+)*)/
       keys = Regexp.union @tag_shortcut.keys.sort_by {|k| -k.size }
       @tag_re = /\A(?:#{keys}|\*(?=[^\s]+)|(\p{Word}(?:\p{Word}|:|-)*\p{Word}|\p{Word}+))/
       keys = Regexp.escape @code_attr_delims.keys.join
       @code_attr_delims_re = /\A[#{keys}]/
       keys = Regexp.escape @attr_list_delims.keys.join
       @attr_list_delims_re = /\A\s*([#{keys}])/
-      @embedded_re = /\A(#{Regexp.union(Embedded.engines.keys.map(&:to_s))}):(\s*)/
+      @embedded_re = /\A(#{Regexp.union(Embedded.engines.keys.map(&:to_s))})(?:\s*(?:(.*)))?:(\s*)/
       keys = Regexp.escape ('"\'></='.split(//) + @attr_list_delims.flatten + @code_attr_delims.flatten).uniq.join
       @attr_name = "\\A\\s*([^\0\s#{keys}]+)"
       @quoted_attr_re = /#{@attr_name}\s*=(=?)\s*("|')/
       @code_attr_re = /#{@attr_name}\s*=(=?)\s*/
+
+      splat_prefix = Regexp.escape(options[:splat_prefix])
+      splat_regexp_source = '\A\s*' << splat_prefix << '(?=[^\s]+)'
+      @splat_attrs_regexp = Regexp.new(splat_regexp_source)
     end
 
     # Compile string to Temple expression
     #
     # @param [String] str Slim code
-    # @return [Array] Temple expression representing the code]]
+    # @return [Array] Temple expression representing the code
     def call(str)
       result = [:multi]
       reset(str.split(/\r?\n/), [result])
@@ -180,7 +184,7 @@ module Slim
           @stacks.pop
         end
 
-        # This line's indentation happens lie "between" two other line's
+        # This line's indentation happens to lie "between" two other line's
         # indentation:
         #
         #   hello
@@ -238,7 +242,9 @@ module Slim
         @stacks << block
       when @embedded_re
         # Embedded template detected. It is treated as block.
-        @stacks.last << [:slim, :embedded, $1, parse_text_block($', @orig_line.size - $'.size + $2.size)]
+        @line = $2
+        attrs = parse_attributes
+        @stacks.last << [:slim, :embedded, $1, parse_text_block($', @orig_line.size - $'.size + $2.size), attrs]
       when /\Adoctype\b/
         # Found doctype declaration
         @stacks.last << [:html, :doctype, $'.strip]
@@ -362,7 +368,11 @@ module Slim
         # Block expansion
         @line = $'
         if @line =~ @embedded_re
-          tag << [:slim, :embedded, $1, parse_text_block($', @orig_line.size - @line.size + $2.size)]
+
+          # Parse attributes
+          @line = $2
+          attrs = parse_attributes
+          tag << [:slim, :embedded, $1, parse_text_block($', @orig_line.size - $'.size + $2.size), attrs]
         else
           (@line =~ @tag_re) || syntax_error!('Expected tag')
           @line = $' if $1
@@ -401,7 +411,7 @@ module Slim
       end
     end
 
-    def parse_attributes(attributes)
+    def parse_attributes(attributes = [:html, :attrs])
       # Check to see if there is a delimiter right after the tag name
       delimiter = nil
       if @line =~ @attr_list_delims_re
@@ -416,7 +426,7 @@ module Slim
 
       while true
         case @line
-        when /\A\s*\*(?=[^\s]+)/
+        when @splat_attrs_regexp
           # Splat attribute
           @line = $'
           attributes << [:slim, :splat, parse_ruby_code(delimiter)]
@@ -457,6 +467,7 @@ module Slim
           end
         end
       end
+      attributes || [:html, :attrs]
     end
 
     def parse_ruby_code(outer_delimiter)
@@ -523,7 +534,7 @@ module Slim
       line = @orig_line.lstrip
       column = (@orig_line && @line ? @orig_line.size - @line.size : 0) + line.size - @orig_line.size
       warn %{Deprecated syntax: #{message}
-  #{options[:file]}, Line #{@lineno}, Column #{@column}
+  #{options[:file]}, Line #{@lineno}, Column #{column + 1}
     #{line}
     #{' ' * column}^
 }
